package moe.oko.opennaw;

import moe.oko.opennaw.command.CityCommand;
import moe.oko.opennaw.command.NationCommand;
import moe.oko.opennaw.util.*;
import net.luckperms.api.LuckPerms;
import org.bukkit.Bukkit;
import org.bukkit.plugin.java.JavaPlugin;
import org.dynmap.DynmapCommonAPI;
import org.dynmap.DynmapCommonAPIListener;
import org.dynmap.bukkit.DynmapPlugin;

import static moe.oko.opennaw.util.CommandHelper.info;

public final class OpenNAW extends JavaPlugin {

    public static OpenNAW instance;
    public NationHandler nationHandler;
    public CityHandler cityHandler;
    public GroupHandler groupHandler;
    private LuckPerms luckPerms;

    private DynmapHandler dynmapHandler;

    private boolean dynmapEnabled;

    public static OpenNAW getInstance() {
        return instance;
    }

    public NationHandler getNationHandler() {
        return nationHandler;
    }
    public CityHandler getCityHandler(){ return cityHandler; }
    public GroupHandler getGroupHandler() { return groupHandler; }

    @Override
    public void onEnable() {
        // Initialize internals
        instance = this;
        this.luckPerms = getServer().getServicesManager().load(LuckPerms.class);
        nationHandler = new NationHandler();
        cityHandler = new CityHandler();
        groupHandler = new GroupHandler(this.luckPerms);

        info("OpenNAW is enabled!");

        // Register Commands & Events
        this.getCommand("nation").setExecutor(new NationCommand());
        this.getCommand("city").setExecutor(new CityCommand());
        getServer().getPluginManager().registerEvents(new ChatHandler(), this);

        if(Bukkit.getPluginManager().isPluginEnabled("dynmap")) {
            this.dynmapEnabled = true;
            //Only initialize if dyn is loaded.
            dynmapHandler = new DynmapHandler();
        }
    }

    @Override
    public void onDisable() {
        info("OpenNAW is disabled!");
    }

    public boolean isDynmapEnabled() {
        return dynmapEnabled;
    }

    public DynmapHandler getDynmapHandler() {
        return dynmapHandler;
    }
}
